@@ -19,7 +19,7 @@ def autodiscover():
 
     mods = [(app_config.name, app_config.module) for app_config in apps.get_app_configs()]
 
-    for (app, mod) in mods:
+    for app, mod in mods:
         # Attempt to import the app's translation module.
         module = '%s.translation' % app
         before_import_registry = copy.copy(translator._registry)
@@ -40,6 +40,9 @@ def autodiscover():
     for module in TRANSLATION_FILES:
         import_module(module)
 
+    # This executes 'after imports' scheduled operations
+    translator.execute_lazy_operations()
+
     # In debug mode, print a list of registered models and pid to stdout.
     # Note: Differing model order is fine, we don't rely on a particular
     # order, as far as base classes are registered before subclasses.
